@@ -27,13 +27,9 @@
 #
 
 import sys
+sys.path.insert(1,"/usr/lib/python2.6/dist-packages")
+
 import os
-
-dist_packages = "/usr/lib/python%d.%d/dist-packages" % (sys.version_info[0], sys.version_info[1])
-
-if os.path.isdir(dist_packages):
-    sys.path.insert(1,dist_packages)
-
 import pwd
 import grp
 import traceback
