@@ -27,12 +27,7 @@
 #
 
 import sys
-import os
-
-dist_packages = "/usr/lib/python%d.%d/dist-packages" % (sys.version_info[0], sys.version_info[1])
-
-if os.path.isdir(dist_packages):
-    sys.path.insert(1,dist_packages)
+sys.path.insert(1,"/usr/lib/python2.6/dist-packages")
 
 import base64
 import cgi
@@ -43,6 +38,7 @@ import errno
 import fcntl
 import mailproc
 import MySQLdb
+import os
 import re
 import smtplib
 import string
